---
Title: Execution Model
---
<Steps titleSize="h3">
    <Step title="Run a flow to completion">
    `flow.run()`
    </Step>

    <Step title="Run a task to completion">
    `task.run()`
    </Step>

    <Step title="Run a task once">
    `task.run_once()`
    </Step>
    
    <Step title="Run an agent">
    `agent.run()`
    </Step>
</Steps>